UNWIND_LIST = "_unwind"

# reversible methods
UPDATE = "update"
APPEND = "append"
INSERT = "insert"
REMOVE = "remove"
RESET = "reset"
IADD = "__iadd__"
ISUB = "__isub__"
IMUL = "__imul__"
IDIV = "__itruediv__"

# other methods
SELECT = "select"
